<?php

class MionPub extends BaseMionPub
{

    public function getNext()
    {
        if($this->getCreatedAt())
        {
            $c = new Criteria();
            $c->add(MionPubPeer::CREATED_AT, $this->getCreatedAt(), Criteria::GREATER_THAN);
            $c->addAscendingOrderByColumn(MionPubPeer::CREATED_AT);
            return MionPubPeer::doSelectOne($c);
        }
        else
            return null;
    }

    public function getPrev()
    {
        if($this->getCreatedAt())
        {
            $c = new Criteria();
            $c->add(MionPubPeer::CREATED_AT, $this->getCreatedAt(), Criteria::LESS_THAN);
            $c->addDescendingOrderByColumn(MionPubPeer::CREATED_AT);
            return MionPubPeer::doSelectOne($c);
        }
        else
            return null;
    }

    function __toString()
    {
        return $this->getTemat();
    }

    public function getParsedTresc()
    {
        return Functions::parseCiCode(parent::getTresc());
    }

    public function save(PropelPDO $con = null)
    {
        if(is_null($con))
        {
            $con = Propel::getConnection(MionPubPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
        }

        $con->beginTransaction();
        try
        {
            $ret = parent::save($con);

            $this->updateLuceneIndex();

            $con->commit();

            return $ret;
        }
        catch (Exception $e)
        {
            $con->rollBack();
            throw $e;
        }
    }

    public function delete(PropelPDO $con = null)
    {
        // aktualizacja indexu Lucene
        $index = Functions::getLuceneIndex('mion');
        foreach($index->find('pk:'.$this->getId()) as $hit)
            $index->delete($hit->id);

        return parent::delete($con);
    }

    /**
     * metoda aktualizujaca indeks Lucene
     * @author      Tomasz Glowinski, 2014
     */
    public function updateLuceneIndex()
    {
        $index = Functions::getLuceneIndex('mion');

        // remove existing entries
        foreach($index->find('pk:'.$this->getId()) as $hit)
            $index->delete($hit->id);

        $doc = new Zend_Search_Lucene_Document();

        // store job primary key to identify it in the search results
        $doc->addField(Zend_Search_Lucene_Field::Keyword('pk', $this->getId()));

        // index job fields
        $culture = sfContext::getInstance()->getUser()->getCulture();
        $jezyk = Zend_Search_Lucene_Field::UnStored('jezyk', $culture, 'utf-8');
        $doc->addField($jezyk);
        $tytul = Zend_Search_Lucene_Field::UnStored('tytul', strip_tags($this->getTemat()), 'utf-8');
        $doc->addField($tytul);
        $zajawka = Zend_Search_Lucene_Field::UnStored('zajawka', strip_tags($this->getZajawka()), 'utf-8');
        $doc->addField($zajawka);
        $tresc = Zend_Search_Lucene_Field::UnStored('tresc', strip_tags($this->getTresc()), 'utf-8');
        $doc->addField($tresc);

        // add job to the index
        $index->addDocument($doc);

        $index->optimize();

        $index->commit();
    }

}
